# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

from traits.api import HasTraits, Map


class Person(HasTraits):
    married = Map({'yes': 1, 'no': 0}, default_value="yes")
    married_2 = Map([], default_value="yes")  # E: arg-type


p = Person()

p.married = "yes"



# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

# configure_traits.py -- Sample code to demonstrate configure_traits()

# --[Imports]------------------------------------------------------------------
from traits.api import HasTraits, Str, Int


# --[Code]---------------------------------------------------------------------
class SimpleEmployee(HasTraits):
    first_name = Str
    last_name = Str
    department = Str

    employee_number = Str
    salary = Int


sam = SimpleEmployee()
sam.configure_traits()



# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

from traits.api import HasTraits, Tuple


class Test(HasTraits):
    var = Tuple(1, 2, 3)


obj = Test()
obj.var = "5"  # E: assignment
obj.var = 5  # E: assignment

obj.var = False  # E: assignment
obj.var = 5.5  # E: assignment

obj.var = 5 + 4j  # E: assignment
obj.var = True  # E: assignment

obj.var = (True,)



# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

# temp_wildcard.py --- Example of using a wildcard with a trait
#                 attribute name

# --[Imports]------------------------------------------------------------------
from traits.api import Any, HasTraits


# --[Code]---------------------------------------------------------------------
class Person(HasTraits):
    temp_ = Any



# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

# wildcard_rules.py --- Example of trait attribute wildcard rules

# --[Imports]------------------------------------------------------------------
from traits.api import Any, HasTraits, Int, Python


# --[Code]---------------------------------------------------------------------
class Person(HasTraits):
    temp_count = Int(-1)
    temp_ = Any
    _ = Python
